@@ -12,33 +12,35 @@ from prompt_toolkit.history import InMemoryHistory
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.completion import WordCompleter
 from .chat import Chat, Tokenizer
-from .agent import BashAgent
+from .agent import CodeAgent
 
 EXAMPLE_TEMPLATE = example_path = os.path.join(gptutil.__path__[0], "example", "assistant.yaml")
 
+
 def replace_commands(input_str):
     def replace_env_var(match):
-        return os.environ.get(match.group(1), '')
+        return os.environ.get(match.group(1), "")
 
     def replace_command(match):
         try:
             result = subprocess.check_output(match.group(1), shell=True, text=True)
             return result.strip()
         except subprocess.CalledProcessError:
-            return ''
+            return ""
 
     # 環境変数を置き換える
-    replaced_str = re.sub(r'\${(\w+)}', replace_env_var, input_str)
+    replaced_str = re.sub(r"\${(\w+)}", replace_env_var, input_str)
     # コマンドを置き換える
-    replaced_str = re.sub(r'`(\w+)`', replace_command, replaced_str)
+    replaced_str = re.sub(r"`(\w+)`", replace_command, replaced_str)
     return replaced_str
 
+
 class CLIHandler:
     def __init__(self, template):
         self.template = template
         self.assistant_name = None
         self.chat = Chat()
-        self.bash_agent = BashAgent()
+        self.code_agent = CodeAgent()
         self.tokenizer = Tokenizer()
         self.data = {}
 
@@ -93,9 +95,9 @@ class CLIHandler:
                     self.data[item["name"]] = command
             answer = self.chat.ask(assistant["user_prompt"].format(**self.data))
             agent = assistant.get("agent", {})
-            if agent.get("name") == "bash":
+            if agent.get("name") == "code":
                 while True:
-                    cmd_result = self.bash_agent.run(answer)
+                    cmd_result = self.code_agent.run(answer)
                     print("\033[32m" + cmd_result + "\033[0m")
                     if cmd_result == "":
                         cmd_result = replace_commands(agent.get("args", ""))
